
#ifndef KRESOURCES_EXPORT_H
#define KRESOURCES_EXPORT_H

#ifdef KRESOURCES_STATIC_DEFINE
#  define KRESOURCES_EXPORT
#  define KRESOURCES_NO_EXPORT
#else
#  ifndef KRESOURCES_EXPORT
#    ifdef kresources_EXPORTS
        /* We are building this library */
#      define KRESOURCES_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define KRESOURCES_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef KRESOURCES_NO_EXPORT
#    define KRESOURCES_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef KRESOURCES_DEPRECATED
#  define KRESOURCES_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef KRESOURCES_DEPRECATED_EXPORT
#  define KRESOURCES_DEPRECATED_EXPORT KRESOURCES_EXPORT KRESOURCES_DEPRECATED
#endif

#ifndef KRESOURCES_DEPRECATED_NO_EXPORT
#  define KRESOURCES_DEPRECATED_NO_EXPORT KRESOURCES_NO_EXPORT KRESOURCES_DEPRECATED
#endif

#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef KRESOURCES_NO_DEPRECATED
#    define KRESOURCES_NO_DEPRECATED
#  endif
#endif

#endif /* KRESOURCES_EXPORT_H */
